@@ -5,9 +5,14 @@
 
     Basic token types and the standard tokens.
 
-    :copyright: 2006 by Georg Brandl.
-    :license: BSD, see LICENSE for more details.
+    :copyright: Copyright 2006-2009 by the Pygments team, see AUTHORS.
+    :license: BSD, see LICENSE for details.
 """
+try:
+    set
+except NameError:
+    from sets import Set as set
+
 
 class _TokenType(tuple):
     parent = None
@@ -21,11 +26,22 @@ class _TokenType(tuple):
         buf.reverse()
         return buf
 
+    def __init__(self, *args):
+        # no need to call super.__init__
+        self.subtypes = set()
+
+    def __contains__(self, val):
+        return self is val or (
+            type(val) is self.__class__ and
+            val[:len(self)] == self
+        )
+
     def __getattr__(self, val):
         if not val or not val[0].isupper():
-            return tuple.__getattr__(self, val)
+            return tuple.__getattribute__(self, val)
         new = _TokenType(self + (val,))
         setattr(self, val, new)
+        self.subtypes.add(new)
         new.parent = self
         return new
 
@@ -40,6 +56,7 @@ Token       = _TokenType()
 
 # Special token types
 Text        = Token.Text
+Whitespace  = Text.Whitespace
 Error       = Token.Error
 # Text that doesn't belong to this lexer (e.g. HTML in PHP)
 Other       = Token.Other
@@ -50,21 +67,53 @@ Name        = Token.Name
 Literal     = Token.Literal
 String      = Literal.String
 Number      = Literal.Number
-Punctuation = Literal.Punctuation
+Punctuation = Token.Punctuation
 Operator    = Token.Operator
 Comment     = Token.Comment
 
 # Generic types for non-source code
 Generic     = Token.Generic
 
+# String and some others are not direct childs of Token.
+# alias them:
+Token.Token = Token
+Token.String = String
+Token.Number = Number
+
 
 def is_token_subtype(ttype, other):
-    """Return True if ``ttype`` is a subtype of ``other``."""
-    while ttype is not None:
-        if ttype == other:
-            return True
-        ttype = ttype.parent
-    return False
+    """
+    Return True if ``ttype`` is a subtype of ``other``.
+
+    exists for backwards compatibility. use ``ttype in other`` now.
+    """
+    return ttype in other
+
+
+def string_to_tokentype(s):
+    """
+    Convert a string into a token type::
+
+        >>> string_to_token('String.Double')
+        Token.Literal.String.Double
+        >>> string_to_token('Token.Literal.Number')
+        Token.Literal.Number
+        >>> string_to_token('')
+        Token
+
+    Tokens that are already tokens are returned unchanged:
+
+        >>> string_to_token(String)
+        Token.Literal.String
+    """
+    if isinstance(s, _TokenType):
+        return s
+    if not s:
+        return Token
+    node = Token
+    for item in s.split('.'):
+        node = getattr(node, item)
+    return node
 
 
 # Map standard token types to short names, used in CSS class naming.
@@ -74,12 +123,14 @@ STANDARD_TYPES = {
     Token:                         '',
 
     Text:                          '',
+    Whitespace:                    'w',
     Error:                         'err',
     Other:                         'x',
 
     Keyword:                       'k',
     Keyword.Constant:              'kc',
     Keyword.Declaration:           'kd',
+    Keyword.Namespace:             'kn',
     Keyword.Pseudo:                'kp',
     Keyword.Reserved:              'kr',
     Keyword.Type:                  'kt',
@@ -136,6 +187,7 @@ STANDARD_TYPES = {
     Comment.Multiline:             'cm',
     Comment.Preproc:               'cp',
     Comment.Single:                'c1',
+    Comment.Special:               'cs',
 
     Generic:                       'g',
     Generic.Deleted:               'gd',
@@ -149,21 +201,3 @@ STANDARD_TYPES = {
     Generic.Subheading:            'gu',
     Generic.Traceback:             'gt',
 }
-
-
-
-if __name__ == '__main__':
-    import sys
-    # sanity check for token name dict: no duplicate entries!
-    s = STANDARD_TYPES.copy()
-    s[Token] = '---' # Token and Text do conflict, that is okay
-    t = {}
-    for k, v in s.iteritems():
-        t.setdefault(v, []).append(k)
-    if len(t) == len(s):
-        print 'Okay!'
-        sys.exit()
-
-    for k, v in t.iteritems():
-        if len(v) > 1:
-            print "%r has more than one key: %r" % (k, v)
